@@ -536,16 +536,6 @@ where
     where
         I: Interface,
     {
-        // FIXME Hold a lock to the interface until the signal is emitted.
-        // This is a workaround for `Invalid client serial` errors.
-        // See https://github.com/flatpak/xdg-dbus-proxy/issues/46
-        let iface_ref = self
-            .connection
-            .object_server()
-            .interface::<_, I>(OBJECT_PATH)
-            .await?;
-        let _guard = iface_ref.get_mut().await;
-
         self.connection
             .emit_signal(
                 None::<BusName<'_>>,
